==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/LoT/AwsIoTHttpProtocol.md <==
# AwsIoTHttpProtocol


```text
aws-q3-2021/Resource/LoT/AwsIoTHttpProtocol
```

```text
include('aws-q3-2021/Resource/LoT/AwsIoTHttpProtocol')
```



| Illustration | AwsIoTHttpProtocol | AwsIoTHttpProtocolCard | AwsIoTHttpProtocolGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/LoT/AwsIoTHttpProtocol.png) | ![illustration for AwsIoTHttpProtocol](../../../aws-q3-2021/Resource/LoT/AwsIoTHttpProtocol.Local.png) | ![illustration for AwsIoTHttpProtocolCard](../../../aws-q3-2021/Resource/LoT/AwsIoTHttpProtocolCard.Local.png) | ![illustration for AwsIoTHttpProtocolGroup](../../../aws-q3-2021/Resource/LoT/AwsIoTHttpProtocolGroup.Local.png) |




## AwsIoTHttpProtocol

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTHttpProtocol
include('aws-q3-2021/Resource/LoT/AwsIoTHttpProtocol')

' renders the element
AwsIoTHttpProtocol('AwsIoTHttpProtocol', 'Aws Io T Http Protocol', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTHttpProtocol
include('aws-q3-2021/Resource/LoT/AwsIoTHttpProtocol')

' renders the element
AwsIoTHttpProtocol('AwsIoTHttpProtocol', 'Aws Io T Http Protocol', 'an optional tech label')
@enduml
```

## AwsIoTHttpProtocolCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTHttpProtocolCard
include('aws-q3-2021/Resource/LoT/AwsIoTHttpProtocol')

' renders the element
AwsIoTHttpProtocolCard('AwsIoTHttpProtocolCard', 'Aws Io T Http Protocol Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTHttpProtocolCard
include('aws-q3-2021/Resource/LoT/AwsIoTHttpProtocol')

' renders the element
AwsIoTHttpProtocolCard('AwsIoTHttpProtocolCard', 'Aws Io T Http Protocol Card', 'an optional description')
@enduml
```

## AwsIoTHttpProtocolGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTHttpProtocolGroup
include('aws-q3-2021/Resource/LoT/AwsIoTHttpProtocol')

' renders the element
AwsIoTHttpProtocolGroup('AwsIoTHttpProtocolGroup', 'Aws Io T Http Protocol Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTHttpProtocolGroup
include('aws-q3-2021/Resource/LoT/AwsIoTHttpProtocol')

' renders the element
AwsIoTHttpProtocolGroup('AwsIoTHttpProtocolGroup', 'Aws Io T Http Protocol Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-7.1.0.tgz: package/distribution/aws-q3-2021/Resource/LoT/AwsIoTHttpProtocol.md <==
# AwsIoTHttpProtocol


```text
aws-q3-2021/Resource/LoT/AwsIoTHttpProtocol
```

```text
include('aws-q3-2021/Resource/LoT/AwsIoTHttpProtocol')
```



| Illustration | AwsIoTHttpProtocol | AwsIoTHttpProtocolCard | AwsIoTHttpProtocolGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/LoT/AwsIoTHttpProtocol.png) | ![illustration for AwsIoTHttpProtocol](../../../aws-q3-2021/Resource/LoT/AwsIoTHttpProtocol.Local.png) | ![illustration for AwsIoTHttpProtocolCard](../../../aws-q3-2021/Resource/LoT/AwsIoTHttpProtocolCard.Local.png) | ![illustration for AwsIoTHttpProtocolGroup](../../../aws-q3-2021/Resource/LoT/AwsIoTHttpProtocolGroup.Local.png) |




## AwsIoTHttpProtocol

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTHttpProtocol
include('aws-q3-2021/Resource/LoT/AwsIoTHttpProtocol')

' renders the element
AwsIoTHttpProtocol('AwsIoTHttpProtocol', 'Aws Io T Http Protocol', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTHttpProtocol
include('aws-q3-2021/Resource/LoT/AwsIoTHttpProtocol')

' renders the element
AwsIoTHttpProtocol('AwsIoTHttpProtocol', 'Aws Io T Http Protocol', 'an optional tech label')
@enduml
```

## AwsIoTHttpProtocolCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTHttpProtocolCard
include('aws-q3-2021/Resource/LoT/AwsIoTHttpProtocol')

' renders the element
AwsIoTHttpProtocolCard('AwsIoTHttpProtocolCard', 'Aws Io T Http Protocol Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTHttpProtocolCard
include('aws-q3-2021/Resource/LoT/AwsIoTHttpProtocol')

' renders the element
AwsIoTHttpProtocolCard('AwsIoTHttpProtocolCard', 'Aws Io T Http Protocol Card', 'an optional description')
@enduml
```

## AwsIoTHttpProtocolGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTHttpProtocolGroup
include('aws-q3-2021/Resource/LoT/AwsIoTHttpProtocol')

' renders the element
AwsIoTHttpProtocolGroup('AwsIoTHttpProtocolGroup', 'Aws Io T Http Protocol Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTHttpProtocolGroup
include('aws-q3-2021/Resource/LoT/AwsIoTHttpProtocol')

' renders the element
AwsIoTHttpProtocolGroup('AwsIoTHttpProtocolGroup', 'Aws Io T Http Protocol Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
